==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/LABORADJUSTMENTS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for LABORADJUSTMENTS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LABORADJUSTMENTS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT0" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT1" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT2" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT3" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT4" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT5" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT6" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT7" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT8" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT9" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LABORADJUSTMENTS_Type", propOrder = {
    "laboradjustment0",
    "laboradjustment1",
    "laboradjustment2",
    "laboradjustment3",
    "laboradjustment4",
    "laboradjustment5",
    "laboradjustment6",
    "laboradjustment7",
    "laboradjustment8",
    "laboradjustment9"
})
public class LABORADJUSTMENTS_Type {

    @XmlElement(name = "LABORADJUSTMENT0")
    protected USERDEFINEDCODEID_Type laboradjustment0;
    @XmlElement(name = "LABORADJUSTMENT1")
    protected USERDEFINEDCODEID_Type laboradjustment1;
    @XmlElement(name = "LABORADJUSTMENT2")
    protected USERDEFINEDCODEID_Type laboradjustment2;
    @XmlElement(name = "LABORADJUSTMENT3")
    protected USERDEFINEDCODEID_Type laboradjustment3;
    @XmlElement(name = "LABORADJUSTMENT4")
    protected USERDEFINEDCODEID_Type laboradjustment4;
    @XmlElement(name = "LABORADJUSTMENT5")
    protected USERDEFINEDCODEID_Type laboradjustment5;
    @XmlElement(name = "LABORADJUSTMENT6")
    protected USERDEFINEDCODEID_Type laboradjustment6;
    @XmlElement(name = "LABORADJUSTMENT7")
    protected USERDEFINEDCODEID_Type laboradjustment7;
    @XmlElement(name = "LABORADJUSTMENT8")
    protected USERDEFINEDCODEID_Type laboradjustment8;
    @XmlElement(name = "LABORADJUSTMENT9")
    protected USERDEFINEDCODEID_Type laboradjustment9;

    /**
     * Gets the value of the laboradjustment0 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT0() {
        return laboradjustment0;
    }

    /**
     * Sets the value of the laboradjustment0 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT0(USERDEFINEDCODEID_Type value) {
        this.laboradjustment0 = value;
    }

    /**
     * Gets the value of the laboradjustment1 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT1() {
        return laboradjustment1;
    }

    /**
     * Sets the value of the laboradjustment1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT1(USERDEFINEDCODEID_Type value) {
        this.laboradjustment1 = value;
    }

    /**
     * Gets the value of the laboradjustment2 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT2() {
        return laboradjustment2;
    }

    /**
     * Sets the value of the laboradjustment2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT2(USERDEFINEDCODEID_Type value) {
        this.laboradjustment2 = value;
    }

    /**
     * Gets the value of the laboradjustment3 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT3() {
        return laboradjustment3;
    }

    /**
     * Sets the value of the laboradjustment3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT3(USERDEFINEDCODEID_Type value) {
        this.laboradjustment3 = value;
    }

    /**
     * Gets the value of the laboradjustment4 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT4() {
        return laboradjustment4;
    }

    /**
     * Sets the value of the laboradjustment4 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT4(USERDEFINEDCODEID_Type value) {
        this.laboradjustment4 = value;
    }

    /**
     * Gets the value of the laboradjustment5 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT5() {
        return laboradjustment5;
    }

    /**
     * Sets the value of the laboradjustment5 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT5(USERDEFINEDCODEID_Type value) {
        this.laboradjustment5 = value;
    }

    /**
     * Gets the value of the laboradjustment6 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT6() {
        return laboradjustment6;
    }

    /**
     * Sets the value of the laboradjustment6 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT6(USERDEFINEDCODEID_Type value) {
        this.laboradjustment6 = value;
    }

    /**
     * Gets the value of the laboradjustment7 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT7() {
        return laboradjustment7;
    }

    /**
     * Sets the value of the laboradjustment7 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT7(USERDEFINEDCODEID_Type value) {
        this.laboradjustment7 = value;
    }

    /**
     * Gets the value of the laboradjustment8 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT8() {
        return laboradjustment8;
    }

    /**
     * Sets the value of the laboradjustment8 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT8(USERDEFINEDCODEID_Type value) {
        this.laboradjustment8 = value;
    }

    /**
     * Gets the value of the laboradjustment9 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT9() {
        return laboradjustment9;
    }

    /**
     * Sets the value of the laboradjustment9 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT9(USERDEFINEDCODEID_Type value) {
        this.laboradjustment9 = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/LABORADJUSTMENTS_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for LABORADJUSTMENTS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="LABORADJUSTMENTS_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT0" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT1" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT2" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT3" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT4" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT5" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT6" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT7" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT8" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LABORADJUSTMENT9" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LABORADJUSTMENTS_Type", propOrder = {
    "laboradjustment0",
    "laboradjustment1",
    "laboradjustment2",
    "laboradjustment3",
    "laboradjustment4",
    "laboradjustment5",
    "laboradjustment6",
    "laboradjustment7",
    "laboradjustment8",
    "laboradjustment9"
})
public class LABORADJUSTMENTS_Type {

    @XmlElement(name = "LABORADJUSTMENT0")
    protected USERDEFINEDCODEID_Type laboradjustment0;
    @XmlElement(name = "LABORADJUSTMENT1")
    protected USERDEFINEDCODEID_Type laboradjustment1;
    @XmlElement(name = "LABORADJUSTMENT2")
    protected USERDEFINEDCODEID_Type laboradjustment2;
    @XmlElement(name = "LABORADJUSTMENT3")
    protected USERDEFINEDCODEID_Type laboradjustment3;
    @XmlElement(name = "LABORADJUSTMENT4")
    protected USERDEFINEDCODEID_Type laboradjustment4;
    @XmlElement(name = "LABORADJUSTMENT5")
    protected USERDEFINEDCODEID_Type laboradjustment5;
    @XmlElement(name = "LABORADJUSTMENT6")
    protected USERDEFINEDCODEID_Type laboradjustment6;
    @XmlElement(name = "LABORADJUSTMENT7")
    protected USERDEFINEDCODEID_Type laboradjustment7;
    @XmlElement(name = "LABORADJUSTMENT8")
    protected USERDEFINEDCODEID_Type laboradjustment8;
    @XmlElement(name = "LABORADJUSTMENT9")
    protected USERDEFINEDCODEID_Type laboradjustment9;

    /**
     * Gets the value of the laboradjustment0 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT0() {
        return laboradjustment0;
    }

    /**
     * Sets the value of the laboradjustment0 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT0(USERDEFINEDCODEID_Type value) {
        this.laboradjustment0 = value;
    }

    /**
     * Gets the value of the laboradjustment1 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT1() {
        return laboradjustment1;
    }

    /**
     * Sets the value of the laboradjustment1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT1(USERDEFINEDCODEID_Type value) {
        this.laboradjustment1 = value;
    }

    /**
     * Gets the value of the laboradjustment2 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT2() {
        return laboradjustment2;
    }

    /**
     * Sets the value of the laboradjustment2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT2(USERDEFINEDCODEID_Type value) {
        this.laboradjustment2 = value;
    }

    /**
     * Gets the value of the laboradjustment3 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT3() {
        return laboradjustment3;
    }

    /**
     * Sets the value of the laboradjustment3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT3(USERDEFINEDCODEID_Type value) {
        this.laboradjustment3 = value;
    }

    /**
     * Gets the value of the laboradjustment4 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT4() {
        return laboradjustment4;
    }

    /**
     * Sets the value of the laboradjustment4 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT4(USERDEFINEDCODEID_Type value) {
        this.laboradjustment4 = value;
    }

    /**
     * Gets the value of the laboradjustment5 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT5() {
        return laboradjustment5;
    }

    /**
     * Sets the value of the laboradjustment5 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT5(USERDEFINEDCODEID_Type value) {
        this.laboradjustment5 = value;
    }

    /**
     * Gets the value of the laboradjustment6 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT6() {
        return laboradjustment6;
    }

    /**
     * Sets the value of the laboradjustment6 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT6(USERDEFINEDCODEID_Type value) {
        this.laboradjustment6 = value;
    }

    /**
     * Gets the value of the laboradjustment7 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT7() {
        return laboradjustment7;
    }

    /**
     * Sets the value of the laboradjustment7 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT7(USERDEFINEDCODEID_Type value) {
        this.laboradjustment7 = value;
    }

    /**
     * Gets the value of the laboradjustment8 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT8() {
        return laboradjustment8;
    }

    /**
     * Sets the value of the laboradjustment8 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT8(USERDEFINEDCODEID_Type value) {
        this.laboradjustment8 = value;
    }

    /**
     * Gets the value of the laboradjustment9 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getLABORADJUSTMENT9() {
        return laboradjustment9;
    }

    /**
     * Sets the value of the laboradjustment9 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setLABORADJUSTMENT9(USERDEFINEDCODEID_Type value) {
        this.laboradjustment9 = value;
    }

}
